@@ -1,10 +1,10 @@
+use super::Text;
 use serde::Deserialize;
 
 pub mod channel;
-pub mod continuation;
 pub mod playlist;
 
-#[derive(Debug, Deserialize)]
+#[derive(Deserialize)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum Result<T> {
     Error { alerts: (Alert,) },
@@ -24,7 +24,7 @@ impl<T> Result<T> {
                     "This playlist type is unviewable." => {
                         Err(crate::Error::Youtube(crate::error::Youtube::Unviewable))
                     }
-                    e => unreachable!("Unknown Error text: '{}'", e),
+                    e => unimplemented!("Unknown Error text: '{}'", e),
                 }
             }
             Self::Ok(ok) => Ok(ok),
@@ -32,13 +32,13 @@ impl<T> Result<T> {
     }
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Alert {
     pub alert_renderer: AlertRenderer,
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Deserialize)]
 pub struct AlertRenderer {
     pub r#type: String,
     pub text: Text,
@@ -48,32 +48,7 @@ impl AlertRenderer {
     fn text(&self) -> &str {
         match &self.text {
             Text::SimpleText(simple_text) => simple_text.simple_text.as_str(),
-            Text::Runs(runs) => runs.runs.0.text.as_str(),
+            Text::Runs(runs) => runs.runs[0].text.as_str(),
         }
     }
 }
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase", untagged)]
-pub enum Text {
-    SimpleText(SimpleText),
-    Runs(Runs),
-}
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct SimpleText {
-    pub simple_text: String,
-}
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Runs {
-    pub runs: (TitleRun,),
-}
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct TitleRun {
-    pub text: String,
-}
